package com.mdd.admin.controller.channel;

import com.mdd.admin.service.IChannelOaReplyDefaultService;
import com.mdd.admin.validate.channel.ChannelRpDefaultValidate;
import com.mdd.admin.validate.commons.IdValidate;
import com.mdd.admin.validate.commons.PageValidate;
import com.mdd.admin.vo.channel.ChannelRpDefaultVo;
import com.mdd.common.core.AjaxResult;
import com.mdd.common.core.PageResult;
import com.mdd.common.validator.annotation.IDMust;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

@RestController
@RequestMapping({"api/channel/oaReplyDefault"})
@Api(
   tags = {"公众号默认回复"}
)
public class ChannelOaReplyDefaultController {
   @Resource
   IChannelOaReplyDefaultService iChannelOaReplyDefaultService;

   @GetMapping({"/list"})
   @ApiOperation("默认回复列表")
   public AjaxResult<PageResult<ChannelRpDefaultVo>> list(@Validated PageValidate pageValidate) {
      PageResult<ChannelRpDefaultVo> list = this.iChannelOaReplyDefaultService.list(pageValidate);
      return AjaxResult.success(list);
   }

   @GetMapping({"/detail"})
   @ApiOperation("默认回复详情")
   public AjaxResult<ChannelRpDefaultVo> detail(@Validated @IDMust @RequestParam("id") Integer id) {
      ChannelRpDefaultVo vo = this.iChannelOaReplyDefaultService.detail(id);
      return AjaxResult.success(vo);
   }

   @PostMapping({"/add"})
   @ApiOperation("默认回复新增")
   public AjaxResult<Object> add(@Validated @RequestBody ChannelRpDefaultValidate defaultValidate) {
      this.iChannelOaReplyDefaultService.add(defaultValidate);
      return AjaxResult.success();
   }

   @PostMapping({"/edit"})
   @ApiOperation("默认回复编辑")
   public AjaxResult<Object> edit(@Validated @RequestBody ChannelRpDefaultValidate defaultValidate) {
      this.iChannelOaReplyDefaultService.edit(defaultValidate);
      return AjaxResult.success();
   }

   @PostMapping({"/del"})
   @ApiOperation("默认回复删除")
   public AjaxResult<Object> del(@Validated @RequestBody IdValidate idValidate) {
      this.iChannelOaReplyDefaultService.del(idValidate.getId());
      return AjaxResult.success();
   }

   @PostMapping({"/status"})
   @ApiOperation("默认回复状态")
   public AjaxResult<Object> status(@Validated @RequestBody IdValidate idValidate) {
      this.iChannelOaReplyDefaultService.status(idValidate.getId());
      return AjaxResult.success();
   }
}
